﻿using System;
using System.Drawing;
using System.Collections.Generic;

namespace EsempioDecorator
{
    public class ObjectStructure
    {
        List<IComponent> _frames = new List<IComponent>();

        public ObjectStructure()
        {
            TextFrame topolino = new TextFrame("Topolino");
            TextFrame pluto = new TextFrame("Pluto");
            _frames.Add(topolino);
            _frames.Add(pluto);
            _frames.Add(new BorderedFrame(topolino));
            _frames.Add(new BorderedFrame(new BorderedFrame(new BorderedFrame(pluto, new Pen(Color.Red, 5)), Color.White), Color.Green));
            _frames.Add(new BorderedFrame(new FilledFrame(topolino)));
            _frames.Add(new BorderedFrame(new FilledFrame(new RotatedFrame(pluto), Color.Aquamarine)));
            _frames.Add(new RotatedFrame(new BorderedFrame(new FilledFrame(pluto, Color.Aquamarine))));
            _frames.Add(new RotatedFrame(new BorderedFrame(new RotatedFrame(new FilledFrame(pluto, Color.Aquamarine)))));
            _frames.Add(new BorderedFrame(new BorderedFrame(new BorderedFrame(new RotatedFrame(topolino), Color.Red), Color.White), Color.Green));
            _frames.Add(new RotatedFrame(new BorderedFrame(new BorderedFrame(new BorderedFrame(topolino, Color.Red), Color.White), Color.Green)));
        }

        public void Draw(Graphics g, float x, float y)
        {
            //g.RotateTransform(20);
            foreach (IComponent frame in _frames)
            {
                frame.Draw(g, x, y);
                SizeF sizeF = frame.Measure(g);
                x += sizeF.Width;
                y += sizeF.Height;
            }
        }

        public string ToXML()
        {
            XMLVisitor xmlVisitor = new XMLVisitor();
            foreach (IComponent frame in _frames)
            {
                frame.Accept(xmlVisitor);
            }
            return xmlVisitor.XMLString;
        }

        public void IncreaseBorder()
        {
            BorderVisitor visitor = new BorderVisitor();
            foreach (IComponent frame in _frames)
            {
                frame.Accept(visitor);
            }
        }
    }
}
