﻿using System;
using System.Drawing;

namespace EsempioDecorator
{
    public class TextFrame : IComponent
    {
        private string _text;
        private Font _textFont = null;
        private SolidBrush _textBrush = null;

        public TextFrame(string text)
        {
            _text = text;
        }

        public string Text
        {
            get
            {
                if (_text == null)
                    _text = String.Empty;
                return _text;
            }
            set { _text = value; }
        }

        public Font TextFont
        {
            get
            {
                if (_textFont == null)
                    _textFont = new Font("Arial", 16);
                return _textFont;
            }
            set { _textFont = value; }
        }

        public SolidBrush TextBrush
        {
            get
            {
                if (_textBrush == null)
                    _textBrush = new SolidBrush(Color.Black);
                return _textBrush;
            }
            set { _textBrush = value; }
        }

        #region IComponent Members

        public virtual void Accept(IVisitor v)
        {
            v.Visit(this);
        }

        public virtual void Draw(Graphics g, float x, float y)
        {
            g.DrawString(Text, TextFont, TextBrush, x, y);
        }

        public virtual SizeF Measure(Graphics g)
        {
            return g.MeasureString(Text, TextFont);
        }

        #endregion
    }
}
